@@ -97,6 +97,7 @@ namespace CEC
 
     virtual bool SupportsDeviceType(const cec_device_type UNUSED(type)) const { return true; };
     virtual cec_device_type GetReplacementDeviceType(const cec_device_type type) const { return type; }
+    virtual bool ActiveSourcePending(void) const { return m_iActiveSourcePending != 0; }
 
   protected:
     virtual int HandleActiveSource(const cec_command &command);
@@ -151,15 +152,16 @@ namespace CEC
 
     virtual bool SourceSwitchAllowed(void) { return true; }
 
-    CCECBusDevice *                       m_busDevice;
-    CCECProcessor *                       m_processor;
-    int32_t                               m_iTransmitTimeout;
-    int32_t                               m_iTransmitWait;
-    int8_t                                m_iTransmitRetries;
-    bool                                  m_bHandlerInited;
-    bool                                  m_bOPTSendDeckStatusUpdateOnActiveSource;
-    cec_vendor_id                         m_vendorId;
-    int64_t                               m_iActiveSourcePending;
-    PLATFORM::CMutex                      m_mutex;
+    CCECBusDevice *  m_busDevice;
+    CCECProcessor *  m_processor;
+    int32_t          m_iTransmitTimeout;
+    int32_t          m_iTransmitWait;
+    int8_t           m_iTransmitRetries;
+    bool            m_bHandlerInited;
+    bool            m_bOPTSendDeckStatusUpdateOnActiveSource;
+    cec_vendor_id    m_vendorId;
+    int64_t          m_iActiveSourcePending;
+    PLATFORM::CMutex m_mutex;
+    int64_t          m_iPowerStatusRequested;
   };
 };
